@@ -18,7 +18,16 @@ Including another URLconf
 from django.contrib import admin
 from django.urls import path
 from django.conf.urls.i18n import i18n_patterns
+from artd_promotion.autocomplete import ProductAutocomplete
 
 urlpatterns = i18n_patterns(
-    path("admin/", admin.site.urls),
+    path(
+        "admin/",
+        admin.site.urls,
+    ),
+    path(
+        "product-autocomplete/",
+        ProductAutocomplete.as_view(),
+        name="product-autocomplete",
+    ),
 )
